#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-http2-extra
version:              0.1.3
visibility:           public
id:                   wai-http2-extra-0.1.3-BJVDT1EO0o62kNPInL3uXW
key:                  wai-http2-extra-0.1.3-BJVDT1EO0o62kNPInL3uXW
license:              MIT
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             WAI utilities for HTTP/2
description:          WAI utilities for HTTP/2
category:             Web
abi:                  da4906ed84bffc2836a0b2099c5e6786
exposed:              True
exposed-modules:      Network.Wai.Middleware.Push.Referer
hidden-modules:
    Network.Wai.Middleware.Push.Referer.LRU
    Network.Wai.Middleware.Push.Referer.Manager
    Network.Wai.Middleware.Push.Referer.Multi
    Network.Wai.Middleware.Push.Referer.ParseURL
    Network.Wai.Middleware.Push.Referer.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-http2-extra-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-http2-extra
hs-libraries:         HSwai-http2-extra-0.1.3-BJVDT1EO0o62kNPInL3uXW
depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    http-types-0.12.4-JlSzXn1cYaxE3KCJJlxkWV
    psqueues-0.2.8.3-EeA3RtqwMrxBEodzsDu31
    wai-3.2.4-9U7mEZmQi9i5eOM7qE7ocW warp-3.4.0-LIglPs87CdaJSo2i9x0lm4
    word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:
    /usr/share/doc/haskell-wai-http2-extra/html/wai-http2-extra.haddock

haddock-html:         /usr/share/doc/haskell-wai-http2-extra/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

